@@ -372,6 +372,7 @@ return(scores)
 ############################################################
 
 "score.irt" <- function(stats=NULL,items,keys=NULL,cut=.3,bounds=c(-4,4),mod="logistic")	{
+  .Deprecated(scoreIrt, msg="score.irt has been replaced with scoreIrt")
    message("score.irt is deprecated and has been replaced by scoreIrt, please change your call")
    scoreIrt(stats=stats,items=items,keys=keys,cut=cut,bounds=bounds,mod=mod) }
    
@@ -699,11 +700,11 @@ x.irt <- irt.fa(x.sim$items[,1:nvar],sort=FALSE,plot=FALSE)
 #	ltm.responses <- table2df(x.ltm.sc$score.dat,x.ltm.sc$score.dat[,nvar+1])
 #	ltm.responses <- data.frame(ltm.responses[,c(1:nvar,nvar+3)])
 #	colnames(ltm.responses) <- c(colnames(x.sim$items),"ltm")
-#	ltm.responses  <- psychTools::dfOrder(ltm.responses,c(1:nvar)) 
+#	ltm.responses  <- dfOrder(ltm.responses,c(1:nvar)) 
 
 
 xnvart <- data.frame(x.sim$items,theta = x.sim$theta)
-xnvart <- psychTools::dfOrder(xnvart,c(1:nvar))
+xnvart <- dfOrder(xnvart,c(1:nvar))
 
 x.fsall <- psych::factor.scores(xnvart[1:nvar],x.irt$fa,method="regression")$scores
 x.df <- data.frame(xnvart, fs=x.fsall)
