@@ -346,8 +346,11 @@ lmCor = {
            print(object$coefficients,digits)
            cat("\nMultiple R \n") 
            print(object$R,digits)
-            cat("\nMultiple R2 \n") 
+            cat("\nMultiple R2 \n")
+            
            print(object$R2,digits)
+           cat("\nZero order correlations \n")
+           print(object$r0,digits)
              cat("\nCohen's set correlation R2 \n") 
            print(object$Rset,digits)
            cat("\nSquared Canonical Correlations\n")
